==> universally-5.1.1.tar.gz: lib/component/tab_bar.dart <==
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:universally/universally.dart';

class BasicTabBar extends TabBar {
  BasicTabBar({
    super.key,
    super.controller,
    super.isScrollable = false,
    super.padding,
    super.automaticIndicatorColorAdjustment = true,
    super.indicatorWeight = 2.0,
    super.indicatorPadding = EdgeInsets.zero,
    super.indicator,
    super.indicatorSize = TabBarIndicatorSize.label,
    super.dividerColor,
    super.labelPadding,
    super.dragStartBehavior = DragStartBehavior.start,
    super.overlayColor,
    super.mouseCursor,
    super.enableFeedback,
    super.onTap,
    super.physics,
    super.splashFactory,
    super.splashBorderRadius,
    TextStyle? labelStyle,
    TextStyle? unselectedLabelStyle,
    Color? indicatorColor,
    Color? labelColor,
    super.unselectedLabelColor = UCS.black70,
    String? fontFamily,
    FontType? fontType,
    double fontSize = 16,
    double height = 38,
    List<Widget>? tabs,
    List<String>? list,
  })  : assert(tabs != null || list != null),
        super(
            tabs: tabs ??
                list?.builder((value) => Tab(text: value, height: height)) ??
                [],
            labelColor: labelColor ?? GlobalConfig().currentColor,
            indicatorColor:
                indicatorColor ?? labelColor ?? GlobalConfig().currentColor,
            labelStyle: labelStyle ??
                TStyle(
                    fontFamily: fontFamily,
                    fontSize: fontSize,
                    fontType: fontType),
            unselectedLabelStyle: unselectedLabelStyle ??
                TStyle(
                    fontFamily: fontFamily,
                    fontSize: fontSize,
                    fontType: fontType));

  BasicTabBar.indicator({
    super.key,
    super.controller,
    super.isScrollable = false,
    super.padding,
    super.automaticIndicatorColorAdjustment = true,
    super.labelPadding,
    super.dragStartBehavior = DragStartBehavior.start,
    super.overlayColor,
    super.mouseCursor,
    super.enableFeedback,
    super.onTap,
    super.physics,
    super.splashFactory,
    super.splashBorderRadius,
    TextStyle? labelStyle,
    TextStyle? unselectedLabelStyle,
    Color? indicatorColor,
    Color labelColor = UCS.white,
    Color unselectedLabelColor = UCS.black70,
    String? fontFamily,
    FontType? fontType,
    double fontSize = 16,
    double height = 38,
    List<Widget>? tabs,
    List<String>? list,
  })  : assert(tabs != null || list != null),
        super(
            tabs: tabs ??
                list?.builder((value) => Tab(text: value, height: height)) ??
                [],
            indicatorWeight: 0,
            indicatorSize: TabBarIndicatorSize.tab,
            indicator: BoxDecoration(
                color: indicatorColor ?? GlobalConfig().currentColor,
                borderRadius: BorderRadius.circular(4)),
            labelColor: labelColor,
            dividerColor: UCS.transparent,
            unselectedLabelColor: unselectedLabelColor,
            labelStyle: labelStyle ??
                TStyle(
                    fontFamily: fontFamily,
                    fontSize: fontSize,
                    fontType: fontType),
            unselectedLabelStyle: unselectedLabelStyle ??
                TStyle(
                    fontFamily: fontFamily,
                    fontSize: fontSize,
                    fontType: fontType));
}

==> universally-6.0.0.tar.gz: lib/component/tab_bar.dart <==
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:universally/universally.dart';

class BaseTabBar extends TabBar {
  BaseTabBar({
    super.key,
    super.controller,
    super.isScrollable = false,
    super.padding,
    super.automaticIndicatorColorAdjustment = true,
    super.indicatorWeight = 2.0,
    super.indicatorPadding = EdgeInsets.zero,
    super.indicator,
    super.indicatorSize = TabBarIndicatorSize.label,
    super.dividerColor,
    super.labelPadding,
    super.dragStartBehavior = DragStartBehavior.start,
    super.overlayColor,
    super.mouseCursor,
    super.enableFeedback,
    super.onTap,
    super.physics,
    super.splashFactory,
    super.splashBorderRadius,
    TextStyle? labelStyle,
    TextStyle? unselectedLabelStyle,
    Color? indicatorColor,
    Color? labelColor,
    super.unselectedLabelColor = UCS.black70,
    String? fontFamily,
    FontType? fontType,
    double fontSize = 16,
    double height = 38,
    List<Widget>? tabs,
    List<String>? list,
  })  : assert(tabs != null || list != null),
        super(
            tabs: tabs ??
                list?.builder((value) => Tab(text: value, height: height)) ??
                [],
            labelColor: labelColor ?? Global().mainColor,
            indicatorColor: indicatorColor ?? labelColor ?? Global().mainColor,
            labelStyle: labelStyle ??
                TStyle(
                    fontFamily: fontFamily,
                    fontSize: fontSize,
                    fontType: fontType),
            unselectedLabelStyle: unselectedLabelStyle ??
                TStyle(
                    fontFamily: fontFamily,
                    fontSize: fontSize,
                    fontType: fontType));

  BaseTabBar.indicator({
    super.key,
    super.controller,
    super.isScrollable = false,
    super.padding,
    super.automaticIndicatorColorAdjustment = true,
    super.labelPadding,
    super.dragStartBehavior = DragStartBehavior.start,
    super.overlayColor,
    super.mouseCursor,
    super.enableFeedback,
    super.onTap,
    super.physics,
    super.splashFactory,
    super.splashBorderRadius,
    TextStyle? labelStyle,
    TextStyle? unselectedLabelStyle,
    Color? indicatorColor,
    Color labelColor = UCS.white,
    Color unselectedLabelColor = UCS.black70,
    String? fontFamily,
    FontType? fontType,
    double fontSize = 16,
    double height = 38,
    List<Widget>? tabs,
    List<String>? list,
  })  : assert(tabs != null || list != null),
        super(
            tabs: tabs ??
                list?.builder((value) => Tab(text: value, height: height)) ??
                [],
            indicatorWeight: 0,
            indicatorSize: TabBarIndicatorSize.tab,
            indicator: BoxDecoration(
                color: indicatorColor ?? Global().mainColor,
                borderRadius: BorderRadius.circular(4)),
            labelColor: labelColor,
            dividerColor: UCS.transparent,
            unselectedLabelColor: unselectedLabelColor,
            labelStyle: labelStyle ??
                TStyle(
                    fontFamily: fontFamily,
                    fontSize: fontSize,
                    fontType: fontType),
            unselectedLabelStyle: unselectedLabelStyle ??
                TStyle(
                    fontFamily: fontFamily,
                    fontSize: fontSize,
                    fontType: fontType));
}
